@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: VideotexP.h,v 1.7 1996/10/31 12:58:14 pierre Exp $"
+#ident "$Id: VideotexP.h,v 1.8 1998/10/02 14:51:13 pierre Exp $"
 
 #ifndef _VideotexP_h
 #define _VideotexP_h
@@ -332,6 +332,17 @@ typedef struct {
     struct position *affichage_GP10[94];
     struct position *affichage_DRCS_courant;
     void (*affiche_chaine_drcs)();
+    int nb_bits_rouge;
+    int nb_bits_vert;
+    int nb_bits_bleu;
+    int decalage_rouge;
+    int decalage_vert;
+    int decalage_bleu;
+    unsigned long red_mask;
+    unsigned long green_mask;
+    unsigned long blue_mask;
+    XColor color_cache[256];
+    int last_color; 
 #ifndef NO_TVR
     int (*fonctions_lecture_headers[5][5])();
     double x_photo, y_photo;
