@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: demon.h,v 1.9 1998/10/02 15:00:22 pierre Exp $"
+#ident "$Id: demon.h,v 1.10 1998/10/16 08:49:21 pierre Exp $"
 
 #ifndef _demon_h
 #define _demon_h
@@ -68,10 +68,7 @@
 /* Code Videotex d'initialisation du mode HyperTerminal */
 #define INIT1_HYPER "\033:2~\n\033[?{\014\016\033P\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\n\030\nCBMS DService Minitel (Xteld %d.%d.%d)L"
 
-#define INIT2_HYPER "\037UB\033FVOTRE CHOIX:\033D\033R ..\033F\033P PUIS \033D\033S ENVOI 
-\037WB\033D\033S SUITE  \033F\033P PAGE SUIVANTE
-\037XB\033D\033S RETOUR \033F\033P PAGE PRECEDENTE
-\037UO"
+#define INIT2_HYPER "\037UB\033FVOTRE CHOIX:\033D\033R ..\033F\033P PUIS \033D\033S ENVOI \012\037WB\033D\033S SUITE  \033F\033P PAGE SUIVANTE\012\037XB\033D\033S RETOUR \033F\033P PAGE PRECEDENTE\012\037UO"
 
 #define INIT3_HYPER "\037UB\033FNUMERO:\033D\033R ....................\033F\033P + \033D\033S ENVOI"
 
