@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: global.h,v 1.11 1998/10/02 15:01:17 pierre Exp $"
+#ident "$Id: global.h,v 1.13 1999/09/14 11:06:51 pierre Exp $"
 
 #ifndef _global_h
 #define _global_h
@@ -258,6 +258,8 @@ EXTERN char *toolkit_utilise;
 EXTERN Widget bouton_compose;
 EXTERN Widget bouton_procedure;
 EXTERN Widget menu_clavier;
+EXTERN Widget menu_terminal;
+EXTERN Widget menu_fichier;
 EXTERN Widget boite_bas;
 EXTERN Widget btn_direct;
 EXTERN Widget timer_minitel;
