@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xtel.c,v 1.17 1998/10/02 15:08:25 pierre Exp $";
+static char rcsid[] = "$Id: xtel.c,v 1.19 1999/09/07 13:55:37 pierre Exp $";
 
 /*
  * programme principal 
@@ -47,7 +47,7 @@ static Cursor teleph_cursor;
 static Pixmap pixmap_icone = None;
 static Boolean flag_execution = False;
 static char *procedure_executee = NULL;
-static char *copyright_string = "(C)1991-98 LECTRA SYSTEMES & Pierre Ficheux";
+static char *copyright_string = "(C)1991-99 LECTRA-SYSTEMES & Pierre Ficheux";
 static XColor black, white;
 
 /* liste des noms des boutons MINITEL */
@@ -122,6 +122,9 @@ static Boolean defaultFalse = False;
 #define XtNerreur2			"erreur2"
 #define XtNerreur3			"erreur3"
 
+#define XtNtypeArret			"typeArret"
+#define XtCTypeArret			"TypeArret"
+
 static XtResource ressources[] = {
     {
 	XtNserveur,
@@ -187,6 +190,13 @@ static XtResource ressources[] = {
 	XtOffsetOf(ressources_xtel, privateColormap),
 	XtRBoolean, (XtPointer) &defaultFalse
 	},
+    {
+	XtNtypeArret,
+	XtCTypeArret,
+	XtRString, sizeof(String),
+	XtOffsetOf(ressources_xtel, typeArret),
+	XtRString, (XtPointer) "0"
+	},
     {
 	XtNstring1,
 	XtCString,
@@ -482,7 +492,10 @@ char **av;
 	i++;
     }
 
-    sprintf (buf, "%s-%d.%d", xtel_basename(av[0]), version_xtel, revision_xtel);
+    if (PATCHLEVEL != 0)
+      sprintf (buf, "%s-%d.%d.%d", xtel_basename(av[0]), version_xtel, revision_xtel, PATCHLEVEL);
+    else
+      sprintf (buf, "%s-%d.%d", xtel_basename(av[0]), version_xtel, revision_xtel);
     XtVaSetValues (topLevel, XtNtitle, buf, XtNiconName, buf, NULL);
 
     /*
