@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xteld.c,v 1.29 1998/10/02 15:13:39 pierre Exp $";
+static char rcsid[] = "$Id: xteld.c,v 1.30 1998/10/16 08:56:06 pierre Exp $";
 
 /*
  * Demon XTELD (communication avec le MODEM)
@@ -40,11 +40,16 @@ static char rcsid[] = "$Id: xteld.c,v 1.29 1998/10/02 15:13:39 pierre Exp $";
  *
  *	- support IAN
  *
+ *   Bernard Fouche (CPIO)
+ *
+ *	- amelioration @pipe
+ *
  */
 
 #define EXTERN
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
 #include "demon.h"
 #include "globald.h"
@@ -545,26 +550,50 @@ char *service_teletel;
 	    exit (1);
 	}
 
-	if (!fork()) { /* fiston */
-#ifdef DEBUG_XTELD
-	    log_debug ("le fiston = %d", getpid());
-#endif
-	    dup2 (tuyau_out[0], 0);
-	    close (tuyau_out[0]);
-	    dup2 (tuyau_in[1], 1);
-	    close (tuyau_in[1]);
-
-	    /* On recupere l'option eventuelle */
-	    option = separe_chaine (code_teletel, ' ');
+ 	if (!fork()) { /* fiston */
+	  char *p, *q, **Argv, End;
+	  int i, Argc = 0;
 
 #ifdef DEBUG_XTELD
-	    log_debug ("code_teletel %s option -%s-", code_teletel, option);
+	  log_debug ("le fiston = %d", getpid());
+#endif
+	  dup2 (tuyau_out[0], 0);
+	  close (tuyau_out[0]);
+	  dup2 (tuyau_in[1], 1);
+	  close (tuyau_in[1]);
+
+	  /* On recupere les options eventuelles */
+	  p = q = code_teletel;
+	  for (;;) {
+	    if ((*p == ' ') || (!*p))
+	      {
+		End = *p;
+		*p = 0;
+		if (!Argc)
+		  Argv = malloc (sizeof (char **));
+		else
+		  Argv = realloc (Argv, (sizeof(char *)*Argc+1));
+		Argv[Argc++] = strdup (q);
+		if (!End)
+		  break;
+		q = ++p;
+	      }
+	    else
+	      p++;
+	  }
+	  Argv = realloc (Argv, (sizeof(char *)*Argc+1));
+	  Argv[Argc] = NULL;
+
+#ifdef DEBUG_XTELD
+	  log_debug ("code_teletel %s", code_teletel);
+	  for (i = 0 ; i <= Argc ; i++)
+	    log_debug ("Argv[%d] = %s", i, Argv[i] ? Argv[i] : "NULL");
 #endif
 
-	    if (execlp (code_teletel, code_teletel, option, NULL) < 0) {
-		log_err ("execlp: %m");
-		exit (1);
-	    }
+	  if (execvp (code_teletel, Argv) < 0) {
+	    log_err ("execlp: %m");
+	    exit (1);
+	  }
 	}
 	else {
 #ifdef DEBUG_XTELD
@@ -867,14 +896,14 @@ char *ch;
 
     do {
 	ret = read (XTELD_INPUT, &l, 1);
-	if (ret < 0) goto err;
+	if (ret <= 0) goto err;
     } while (ret != 1);
 
     ch[l] = 0;
 
     while (l) {
 	ret = read (XTELD_INPUT, ch, l);
-	if (ret < 0) goto err;
+	if (ret <= 0) goto err;
 	l -= ret;
     }
 
@@ -1039,10 +1068,20 @@ static void erase_input (char *str, int size)
   set_cursor (0);
 }
 
-static int input_value (char *str, int max_value, int max_size)
+static int check_value (char *s, int maxv)
+{
+  if ((maxv && (atoi (s) > maxv)) || strlen (s) == 0) {
+    display_control_line ("VALEUR INTERDITE !");
+    return 0;
+  }
+  else
+    return 1;
+}
+
+static int input_value (char *str, int max_value, int max_size, int numeric)
 {
   char c;
-  int ind = 0;
+  int ind = 0, end = 0;
 
   if (max_size > IN_SIZE)
     max_size = IN_SIZE;
@@ -1050,7 +1089,7 @@ static int input_value (char *str, int max_value, int max_size)
   erase_input (str, max_size);
   
   do {
-    if (read (XTELD_INPUT, &c, 1) <0)
+    if (read (XTELD_INPUT, &c, 1) <= 0)
       return -1;
 
 #ifdef DEBUG_XTELD
@@ -1061,19 +1100,18 @@ static int input_value (char *str, int max_value, int max_size)
 
     /* Traitement ENVOI/SUITE/RETOUR.. */
     if (c == 19) {
-      read (XTELD_INPUT, &c, 1);
+      if (read (XTELD_INPUT, &c, 1) <= 0)
+	return -1;
 
       switch (c) {
 
       case 'A' : /* ENVOI */
-
-	if (max_value && (atoi (str) > max_value)) {
-	  display_control_line ("VALEUR INTERDITE !");
+	if (!check_value (str, max_value)) {
 	  erase_input (str, max_size);
 	  ind = 0;
 	}
 	else
-	  c = '\r';
+	  end = 1;
 
 	break;
 
@@ -1118,8 +1156,16 @@ static int input_value (char *str, int max_value, int max_size)
 	break;
       }
     }
+    else if (c == '\r') {
+      if (!check_value (str, max_value)) {
+	erase_input (str, max_size);
+	ind = 0;
+      }
+      else
+	end = 1;
+    }
     else {
-      if (ind < max_size && c != '\r') {
+      if (ind < max_size && (!numeric || (numeric && (c >= '0' && c <= '9')))) {
 	str[ind++] = c;
 	write (XTELD_OUTPUT, &c, 1);
 #ifdef DEBUG_XTELD
@@ -1127,7 +1173,7 @@ static int input_value (char *str, int max_value, int max_size)
 #endif
       }
     }
-  } while (c != '\r');
+  } while (!end);
 
   return (strlen (str));
 }
@@ -1170,7 +1216,7 @@ char *ch;
   erase_control_line (ind);
     
   /* Saisie utilisateur */
-  if (input_value (str_in, nb_services_hyper, 2) < 0)
+  if (input_value (str_in, nb_services_hyper, 2, True) < 0)
     goto err;
 
   iserv = atoi(str_in)-1;
@@ -1179,7 +1225,7 @@ char *ch;
   if (!strcmp (services_hyper[iserv].nom_service, "Direct")) {
     write (XTELD_OUTPUT, INIT3_HYPER, strlen(INIT3_HYPER));
     first_col = 'J';
-    if (input_value (str_in, 0, 20) < 0)
+    if (input_value (str_in, 0, 20, False) < 0)
       goto err;
     strcpy (service, str_in);
     sprintf (buf, "APPEL DIRECT %s", service);
